==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/include/parser.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

/*
   level 0 (Է ״ ǵ )
   level 1 (html ) obsolete !!
   level 2 (ڰ  html ڵ常 밡)
   level 3 (κ극ũ ְ, url,email  ڵ ũ)
   level 4 (html  ϰ κ극ũ )
   level 5 (κ극ũ   & html )
*/

function KWL_ParseContent($input,$level) {
   if ($level == 2) return "<pre class=\"html-story\">" .
      KWL_AntiEmailBot(KWP_ParseHtmlContent($input)) . "</pre>";
   elseif ($level == 3) return nl2br(KWL_AntiEmailBot(KWL_Autolink(KWL_PrepareHtml($input))));
   elseif ($level == 4) return nl2br(KWL_AntiEmailBot(KWL_PrepareHtml($input)));
   elseif ($level == 5) return KWL_AntiEmailBot(KWL_PrepareHtml($input));
   else return $input;
}

function KWL_AntiEmailBot() {
   static $search = array('/([a-z0-9_-])@([a-z0-9_-])/se');
   static $replace = array('"&#" . 
                           sprintf("%03d", ord("\\1")) . 
                           ";&#064;&#" .
                           sprintf("%03d", ord("\\2")) . ";";');

   $ret = array();
   foreach (func_get_args() as $var) {
      $var = preg_replace($search, $replace, $var);
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

function KWL_Autolink() {
   static $source,$target;

   if (!isset($source)) 
      $source = array ('/&((quo|g|l)t)/i',
                    '/(((ht|f)tp|(http|new)s):\/\/(([\xA1-\xFEa-z0-9_\-]+\.[][\xA1-\xFEa-z0-9:;&#@=_~%\?\/\.\,\+\-]+)(\/|[\.]*[a-z0-9])))/i',
                    '/(([\xA1-\xFEa-z0-9_\.\-]+)@([\xA1-\xFEa-z0-9_\-]+\.[a-z0-9\-\._\-]+[\.]*[a-z0-9]))/i',
                    '/!((quo|g|l)t)/i');
   if (!isset($target))
      $target = array ('!\\1',
                    '<a class="clink" title="\\1" href="\\1" target="_blank">\\1</a>',
                    '<a class="clink" href="mailto:NOSPAM.\\1.NOSPAM">\\1</a>',
                    '&\\1');

   $ret = array();
   foreach (func_get_args() as $var) {
      $var = preg_replace($source,$target,$var);
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

function KWP_ParseHtmlContent() {
   static $htmlkey;
   $CONF = KWL_GetConf();

   if (!isset($htmlkey)) {
      $htmlkey = array();
      foreach(KWL_GetConf('HtmlKey') as $key) {
         $htmlkey[] = "|<(/?$key(\s+.*?)?)>|i";
      }
   }
   $ret = array();
   foreach (func_get_args() as $ass) {
      $ass = preg_replace($htmlkey, "\022\\1\024", $ass);
      $ass = KWL_PrepareHtml($ass);
      $target = array ('/\022([^\024]*)\024/e','/<a([^>]*)>/i');
      $source = array ("'<' . strtr('\\1', array('&gt;' => '>', '&lt;' => '<', '&quot;' => '\"', '&amp;' => '&')) . '>';", '<a class="clink"\\1>');
      $ass = preg_replace($target,$source,$ass);

      /* make thumbnail */
      if ($CONF['thumbnail']) {
         
         $exp['http'] = "(http|https|ftp):\/\/(([\xA1-\xFEa-z0-9:_\-]+\.[\xA1-\xFEa-z0-9,:;&#=_~%\[\]?\/.,+\-]+)([.]*[\/a-z0-9\[\]]|=[\xA1-\xFE]+))";
         preg_match_all("/<img([^>]*)src=[\"' ]*({$exp['http']})[\"']*[^>]*>/i",$ass,$matches);

         foreach ($matches[2] as $url) {
            $exp['source'] = "/<img([^>]*)src=[\"' ]*(". preg_quote($url,'/') .")[\"']*[^>]*>/i";
            $exp['target'] = "<a href=\"\\2\" target=\"_blank\"><a href=\"\\2\" target=\"_blank\">";
            $img_size = @GetImageSize($url);
            if (!empty($img_size) && ($img_size[0] > $CONF['thumbx'] || $img_size[1] > $CONF['thumby'])) {

               if (extension_loaded("gd")) {

                  $exp['target'] .= "<img src=\"$CONF[G_URL]/img.php?url=". rawurlencode($url) ."\" width=\"{$CONF['thumb_size']}\" height=\"". intval($img_size[1]/($img_size[0]/$CONF['thumb_size'])) ."\"";
                  
               } else {

                  $exp['target'] .= "<img src=\"\\2\" width=\"{$CONF['thumb_size']}\" height=\"". intval($img_size[1]/($img_size[0]/$CONF['thumb_size'])) ."\"";
               }
               
            } else {
               $exp['target'] .= "<img src=\"\\2\" width=\"{$CONF['thumb_size']}\" height=\"". intval($CONF['thumb_size'] * 0.75) ."\"";
            }
            $exp['target'] .= " vspace=\"0\" hspace=\"0\" title=\""._VIEW_ORIG_FILE."\" alt=\""._VIEW_ORIG_FILE."\" border=\"0\" /></a>";
            $ass = preg_replace($exp['source'],$exp['target'],$ass);
         }
         
      }

      array_push($ret, $ass);
   }

   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

function KWL_PrepareHtml() {
   $ret = array();
   foreach (func_get_args() as $var) {
      $var = KWL_HanCt(htmlspecialchars($var));
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

/* Based on http://jsboard.kldp.org */
function KWL_HanCt() {
   $ret = array();
   foreach (func_get_args() as $var) {
      $var = preg_replace("/&amp;(#|amp)/i","&\\1",$var);
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

/* Based on http://jsboard.kldp.org */
function KWL_StringCut($str,$length,$html=false) {
   if ($html) $str = KWL_UnHtmlSpecialchars($str);
   if (strlen($str) > $length) {
      $str = ereg_replace("\n|\r","",$str);
      $str = substr($str,0,$length);
      $str = preg_replace("/(([\x80-\xFE].)*)[\x80-\xFE]?$/","\\1",$str);
   }
   return $str;
}

function KWL_Author($A) {
   if ($A['Author'] == "Anonymous" && empty($A['AuthorEmail']))
      return _ANONY;
   else
      return "<a href=\"". KWL_GetConf("G_URL") ."/profiles.php?".
      "Author=". urlencode($A['Author']) .
      "&amp;AuthorEmail=". KWL_Rot13($A['AuthorEmail']) .
      "&amp;AuthorURL=". urlencode($A['AuthorURL']) .
      "\">$A[Author]</a>";
}

function KWL_UserVars($vars,$command='') {
   $resarray = array();
   if (!is_array($vars)) $object[] = &$vars;
   else $object = &$vars;
   foreach ($object as $var) {
      global $$var;
      $ourvar = $$var;

      if (!isset($ourvar)) {
         array_push($resarray, NULL);
         continue;
      }
      if (empty($ourvar)) {
         array_push($resarray, $ourvar);
         continue;
      }
      if (!empty($command)) {
         $ourvar = KWL_string_parse($ourvar,$command);
      }
      array_push($resarray, $ourvar);
   }
   if (count($resarray) == 1) return $resarray[0];
   else return $resarray;
}

function KWL_string_parse($var,$command) {
   if (is_array($var)) {
      foreach ($var as $k=>$v) {
         if (is_array($v)) $ret[$k] = $v;
         else $ret[$k] = $command($v);
      }
   } else $ret = $command($var);
   return $ret;
}
?>

==> korweblog-1.6.1.tar.gz: korweblog-1.6.1/include/parser.inc.php <==
<?
/*--------------------------------------------------------------------
   KorWeblog :: Highly Customizable Weblog/CMS
   Copyright (C) 2001-2004 by Im Eunjea <eunjea@kldp.org>
   For detail of license and/or other info, see the file doc/COPYING.
   http://weblog.kldp.org
----------------------------------------------------------------------

LICENSE

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software 
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
----------------------------------------------------------------------*/

/*
   level 0 (Է ״ ǵ )
   level 1 (html ) obsolete !!
   level 2 (ڰ  html ڵ常 밡)
   level 3 (κ극ũ ְ, url,email  ڵ ũ)
   level 4 (html  ϰ κ극ũ )
   level 5 (κ극ũ   & html )
*/

function KWL_ParseContent($input,$level) {
   if ($level == 2) return "<pre class=\"html-story\">" .
      KWL_AntiEmailBot(KWP_ParseHtmlContent($input)) . "</pre>";
   elseif ($level == 3) return nl2br(KWL_AntiEmailBot(KWL_Autolink(KWL_PrepareHtml($input))));
   elseif ($level == 4) return nl2br(KWL_AntiEmailBot(KWL_PrepareHtml($input)));
   elseif ($level == 5) return KWL_AntiEmailBot(KWL_PrepareHtml($input));
   else return $input;
}

function KWL_AntiEmailBot() {
   static $search = array('/([a-z0-9_-])@([a-z0-9_-])/se');
   static $replace = array('"&#" . 
                           sprintf("%03d", ord("\\1")) . 
                           ";&#064;&#" .
                           sprintf("%03d", ord("\\2")) . ";";');

   $ret = array();
   foreach (func_get_args() as $var) {
      $var = preg_replace($search, $replace, $var);
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

function KWL_Autolink() {
   static $source,$target;

   if (!isset($source)) 
      $source = array ('/&((quo|g|l)t)/i',
                    '/(((ht|f)tp|(http|new)s):\/\/(([\xA1-\xFEa-z0-9_\-]+\.[][\xA1-\xFEa-z0-9:;&#@=_~%\?\/\.\,\+\-\*]+)(\/|[\.]*[a-z0-9])))/i',
                    '/(([\xA1-\xFEa-z0-9_\.\-]+)@([\xA1-\xFEa-z0-9_\-]+\.[a-z0-9\-\._\-]+[\.]*[a-z0-9]))/i',
                    '/!((quo|g|l)t)/i');
   if (!isset($target))
      $target = array ('!\\1',
                    '<a class="clink" title="\\1" href="\\1" target="new">\\1</a>',
                    '<a class="clink" href="mailto:NOSPAM.\\1.NOSPAM">\\1</a>',
                    '&\\1');

   $ret = array();
   foreach (func_get_args() as $var) {
      $var = preg_replace($source,$target,$var);
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

function KWP_ParseHtmlContent() {
   static $htmlkey;
   $CONF = KWL_GetConf();

   if (!isset($htmlkey)) {
      $htmlkey = array();
      foreach(KWL_GetConf('HtmlKey') as $key) {
         $htmlkey[] = "|<(/?$key(\s+.*?)?)>|i";
      }
   }
   $ret = array();
   foreach (func_get_args() as $ass) {
      $ass = preg_replace($htmlkey, "\022\\1\024", $ass);
      $ass = KWL_PrepareHtml($ass);
      $target = array ('/\022([^\024]*)\024/e','/<a([^>]*)>/i');
      $source = array ("'<' . strtr('\\1', array('&gt;' => '>', '&lt;' => '<', '&quot;' => '\"', '&amp;' => '&')) . '>';", '<a class="clink"\\1>');
      $ass = preg_replace($target,$source,$ass);

      /* make thumbnail */
      if ($CONF['thumbnail']) {
         
         $exp['http'] = "(http|https|ftp):\/\/(([\xA1-\xFEa-z0-9:_\-]+\.[\xA1-\xFEa-z0-9,:;&#=_~%\[\]?\/.,+\-]+)([.]*[\/a-z0-9\[\]]|=[\xA1-\xFE]+))";
         preg_match_all("/<img([^>]*)src=[\"' ]*({$exp['http']})[\"']*[^>]*>/i",$ass,$matches);

         foreach ($matches[2] as $url) {
            $exp['source'] = "/<img([^>]*)src=[\"' ]*(". preg_quote($url,'/') .")[\"']*[^>]*>/i";
            $exp['target'] = "<a href=\"\\2\" target=\"new\">";
            $img_size = @GetImageSize($url);
            if (!empty($img_size) && ($img_size[0] > $CONF['thumbx'] || $img_size[1] > $CONF['thumby'])) {

               if (extension_loaded("gd")) {

                  $exp['target'] .= "<img src=\"$CONF[G_URL]/img.php?url=". rawurlencode($url) ."\" width=\"{$CONF['thumb_size']}\" height=\"". intval($img_size[1]/($img_size[0]/$CONF['thumb_size'])) ."\"";
                  
               } else {

                  $exp['target'] .= "<img src=\"\\2\" width=\"{$CONF['thumb_size']}\" height=\"". intval($img_size[1]/($img_size[0]/$CONF['thumb_size'])) ."\"";
               }
               
            } else {
               /* we don't know size of image.
               $exp['target'] .= "<img src=\"\\2\" width=\"{$CONF['thumb_size']}\" height=\"". intval($CONF['thumb_size'] * 0.75) ."\"";
               */
               $exp['target'] .= "<img src=\"\\2\"";
            }
            $exp['target'] .= " vspace=\"0\" hspace=\"0\" title=\""._VIEW_ORIG_FILE."\" alt=\""._VIEW_ORIG_FILE."\" border=\"0\" /></a>";
            $ass = preg_replace($exp['source'],$exp['target'],$ass);
         }
         
      }

      array_push($ret, $ass);
   }

   if (func_num_args() == 1) return ($CONF['wordwrap'] ? wordwrap($ret[0],$CONF['wrap_width'],"\n") : $ret[0]);
   else return ($CONF['wordwrap'] ? wordwrap($ret,$CONF['wrap_width'],"\n") : $ret);
}

function KWL_PrepareHtml() {
   $ret = array();
   foreach (func_get_args() as $var) {
      $var = KWL_HanCt(htmlspecialchars($var));
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

/* Based on http://jsboard.kldp.org */
function KWL_HanCt() {
   $ret = array();
   foreach (func_get_args() as $var) {
      $var = preg_replace("/&amp;(#|amp)/i","&\\1",$var);
      array_push($ret, $var);
   }
   if (func_num_args() == 1) return $ret[0];
   else return $ret;
}

/* Based on http://jsboard.kldp.org */
function KWL_StringCut($str,$length,$html=false) {
   global $rdf_lang;
   if ($html) $str = KWL_UnHtmlSpecialchars($str);
   if (strlen($str) > $length) {
      $str = preg_replace("/\n|\r/",' ',$str);
      if ($rdf_lang == "utf-8") {
         $str = KWL_Utf8_Substr($str,$length);
      } else {
         $str = substr($str,0,$length);
         $str = preg_replace("/(([\x80-\xFE].)*)[\x80-\xFE]?$/","\\1",$str);
      }
   }
   return $str;
}

/* http://php.net/substr (windix at 263 dot net) */
function KWL_Utf8_Substr($str,$len) {
   preg_match_all("/[\x01-\x7f]|[\xc2-\xdf][\x80-\xbf]|\xe0[\xa0-\xbf][\x80-\xbf]|[\xe1-\xef][\x80-\xbf][\x80-\xbf]|\xf0[\x90-\xbf][\x80-\xbf][\x80-\xbf]|[\xf1-\xf7][\x80-\xbf][\x80-\xbf][\x80-\xbf]/", $str, $match);
   return join("",array_slice($match[0],0,$len));
}

function KWL_Author($A) {
   if ($A['Author'] == "Anonymous" && empty($A['AuthorEmail']))
      return _ANONY;
   else
      return "<a href=\"". KWL_GetConf("G_URL") ."/profiles.php?".
      "Author=". urlencode($A['Author']) .
      "&amp;AuthorEmail=". KWL_Rot13($A['AuthorEmail']) .
      "&amp;AuthorURL=". urlencode($A['AuthorURL']) .
      "\">$A[Author]</a>";
}

function KWL_UserVars($vars,$command='') {
   $resarray = array();
   if (!is_array($vars)) $object[] = &$vars;
   else $object = &$vars;
   foreach ($object as $var) {
      global $$var;
      $ourvar = $$var;

      if (!isset($ourvar)) {
         array_push($resarray, NULL);
         continue;
      }
      if (empty($ourvar)) {
         array_push($resarray, $ourvar);
         continue;
      }
      if (!empty($command)) {
         $ourvar = KWL_string_parse($ourvar,$command);
      }
      array_push($resarray, $ourvar);
   }
   if (count($resarray) == 1) return $resarray[0];
   else return $resarray;
}

function KWL_string_parse($var,$command) {
   if (is_array($var)) {
      foreach ($var as $k=>$v) {
         if (is_array($v)) $ret[$k] = $v;
         else $ret[$k] = $command($v);
      }
   } else $ret = $command($var);
   return $ret;
}
?>
